@@ -282,10 +282,14 @@ gtk_adi_con_view_child_event_destroy (GtkWidget *window, GtkAdiView *self)
     if (!last) return;
     
     GtkAdiContainer * cont = (GtkAdiContainer*)last->data;
-    if (cont && GTK_IS_WIDGET(cont->widget))
-        gtk_adi_internal_send_signal(GTK_ADI_CON_VIEW(self)->adi, ADI_CLOSE_CHILD_S, (gpointer)cont->widget);
-    
-    GTK_ADI_CON_VIEW(self)->containers = g_list_remove(GTK_ADI_CON_VIEW(self)->containers, cont);
+    if (cont) {
+       if(GTK_IS_WIDGET(cont->widget)) {
+          gtk_adi_internal_send_signal(GTK_ADI_CON_VIEW(self)->adi, ADI_CLOSE_CHILD_S, (gpointer)cont->widget);
+       }
+       GTK_ADI_CON_VIEW(self)->containers = g_list_remove(GTK_ADI_CON_VIEW(self)->containers, cont);    
+       g_free (cont);
+       cont = NULL;
+    }
 }
 
 void 
@@ -650,13 +654,14 @@ gtk_adi_con_view_get_child_container (GtkAdiView *self, GtkWidget *widget)
     GtkAdiContainer *child = NULL;
 
     list = g_list_find_custom (GTK_ADI_CON_VIEW(self)->containers,
-                           widget,
-			   gtk_adi_con_view_find_widget);
+                               widget,
+                               gtk_adi_con_view_find_widget);
     if (list != NULL)
     {
-	child = (GtkAdiContainer *) (list->data);
-    }    
-    return child->container;
+        child = (GtkAdiContainer *) (list->data);
+        return child->container;
+    }
+    return NULL;
 }
 
 gint
